@@ -5,7 +5,11 @@ import aiobtclientapi
 
 class Client:
     def __init__(self, config):
-        self._config = config
+        self._config = config.copy()
+
+    @property
+    def config(self):
+        return self._config.copy()
 
     @cached_property
     def api(self):
