@@ -113,7 +113,9 @@ def _setup_debugging(args):
         import logging
         logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
     elif args.debug:
-        _mkdir(os.path.dirname(args.debug))
+        debug_directory = os.path.dirname(args.debug)
+        if debug_directory:
+            _mkdir(debug_directory)
         import logging
         logging.basicConfig(filename=args.debug, level=logging.DEBUG)
 
@@ -321,7 +323,7 @@ def _copy_torrent(config, torrent_path, torrent):
         try:
             shutil.copy(torrent_path, target_filepath)
         except shutil.SameFileError:
-            _debug('Already copied: {target_filepath}')
+            _debug(f'Already copied: {target_filepath}')
         except OSError as e:
             msg = e.strerror if e.strerror else str(e)
             _fatal_error(f'Failed to copy {torrent_path}: {msg}')
